function [P,meansigma]=estsummary(Pires,Sigmares,Phires,MeanUpsilon,StdUpsilon,StructuralForm,K,p)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PURPOSE: 	Computes the posterior estimates and precision measures for the Bayesian VAR model
%
% MODEL:    x_{t}=PI_{1}*x_{t-1}+...+PI_{K}*x_{t-K}+PHI*d_{t}+eps_{t}
%									
% INPUT		Pires:      (niter-by-(p^2)*k) matrix of draws from the posterior of
%                       VAR coefficients.
%           Sigmares:      (niter-by-(p^2)*k) matrix of draws from the posterior of
%                       VAR coefficients.
%           K:          (scalar) number of lags in the VAR.
%           p           (scalar) number of time series in the system.
%
% OUTPUT:   P           (p-by-1 cell array) each P{i} contains the
%                       posterior estimates of the coeff in the ith
%                       equation of the system. First column of P{i}
%                       contains the posterior means, the second col
%                       contains the posterior stds and the third contains
%                       posterior t-ratios. The coefficients are ordered
%                       exactly as in PcGive. The exogenous variables and
%                       the constant are the last coefficients in each
%                       equation.
%           meansigma   (p-by-1) vector with posterior means of the error
%                       variances of the equations.
%           stdsigma   (p-by-1) vector with posterior stds of the error
%                       variances of the equations.
%
% AUTHOR:	Mattias Villani, Research Department, Sveriges Riksbank and Department of Statistics, Stockholm University.
%		    E-mail: mattias.villani@riksbank.se.
%
% REVISED:		2004-10-22
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


q=(size(Pires,2)-p^2*K)/p;

if isempty(Phires)==0
    MeanAdjusted=1;
    qMeanadj=size(Phires,2)/p;
else
    MeanAdjusted=0;
end

if size(Pires,1)==1
    Posteriormeans=invvec(Pires',p*K+q)';
    Posteriorstds=invvec(Pires',p*K+q)';
    if MeanAdjusted==1
        PosteriormeansPhi=invvec(Phires',qMeanadj)';
        PosteriorstdsPhi=invvec(Phires',qMeanadj)';
    end
    if StructuralForm<2
        meansigma=sqrt(diag(invvech(Sigmares',p)));
    else
        meansigma=sqrt(diag(inv(MeanUpsilon*MeanUpsilon')));
    end
else
    Posteriormeans=invvec(mean(Pires)',p*K+q)';
    Posteriorstds=invvec(std(Pires)',p*K+q)';
    if MeanAdjusted==1
        PosteriormeansPhi=invvec(mean(Phires)',qMeanadj)';
        PosteriorstdsPhi=invvec(std(Phires)',qMeanadj)';
    end
    
    if StructuralForm<2
        meansigma=diag(invvech(mean(sqrt(Sigmares))',p));
    else
        meansigma=sqrt(diag(inv(MeanUpsilon*MeanUpsilon')));
    end
end
for i=1:p
    means=Posteriormeans(i,:);
    stds=Posteriorstds(i,:);
    if MeanAdjusted==1
        meansPhi=PosteriormeansPhi(i,:);
        stdsPhi=PosteriorstdsPhi(i,:);
    end
    r=0;
    for t=1:p
        w=t;
        for k=1:K
            r=r+1;
            P{i}(r,1)=means(w);
            P{i}(r,2)=stds(w);
            P{i}(r,3)=means(w)./stds(w);
        w=w+p;
        end
        P{i}(r+1:r+q,1)=means(p*K+1:p*K+q);
        P{i}(r+1:r+q,2)=stds(p*K+1:p*K+q);
        P{i}(r+1:r+q,3)=means(p*K+1:p*K+q)./stds(p*K+1:p*K+q);
    end
    if MeanAdjusted==1
        P{i}(r+1:r+qMeanadj,1)=meansPhi';
        P{i}(r+1:r+qMeanadj,2)=stdsPhi';
        P{i}(r+1:r+qMeanadj,3)=meansPhi'./stdsPhi';
    end
end
